Ngram Extraction
================

.. _n-grams:

Introduction
------------
The ngram_extraction module uses `nltk` to split a given block of text into ngrams.

Usage
-----
To use the module:

.. code-block:: console

    >>> import coast_core
    >>> coast_core.ngram_extraction.function(to_use)


or:

.. code-block:: console

    >>> from coast_core import ngram_extraction
    >>> ngram_extraction.function(to_use)

Functions
---------
.. automodule:: coast_core.ngram_extraction
    :members:
    :undoc-members:
    :show-inheritance:
